# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-25 19:46


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('buttons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='button',
            name='background_color',
            field=models.CharField(blank=True, max_length=6, null=True, verbose_name='Background Color'),
        ),
    ]
